@@ -61,7 +61,7 @@ static char *extension = ".e";
 
 static FILE *in, *out;
 static int eof;
-static int lineno;
+static long lineno;
 static char line[LINELEN];
 static char *curname;
 
@@ -122,9 +122,9 @@ static int get_line()
  * exportdef -- copy a #define to output
  ***************************************************************************/
 static void exportdef(i)
-    int i;
+    long i;
 {
-    unsigned int len;
+    unsigned long len;
 
     /*
      * TO DO: encountering an end of file should produce a suitable error
@@ -151,9 +151,10 @@ static void exportdef(i)
  * export -- copy next declaration to output
  ***************************************************************************/
 static void export(i)
-    int *i;
+    long *i;
 {
-    int brace, paren, squote, dquote, comment, stop, is_typedef;
+    int brace, paren, squote, dquote, comment, stop, is_typedef, start, is_enum,
+      is_extern, is_struct;
 
     /*
      * TO DO: End of file while any of the variables is still
@@ -168,6 +169,10 @@ static void export(i)
     brace = 0;
     stop = 0;
     is_typedef = 0;
+    is_enum = 0;
+    is_extern = 0;
+    is_struct = 0;
+    start = 1;
     do {
         switch (line[*i]) {
 	case '\\':
@@ -179,7 +184,7 @@ static void export(i)
         case '}':
             if (!comment && !squote && !dquote && !paren) brace--;
 	    if (brace < 0) {
-		fprintf(stderr, "%s:%d: syntax error (too many '}'s)\n",
+		fprintf(stderr, "%s:%ld: syntax error (too many '}'s)\n",
 			curname, lineno);
 		err++;
 		brace = 0;
@@ -229,14 +234,14 @@ static void export(i)
 	case '\n':
 	    if (dquote) {
 		fprintf(stderr,
-			"%s:%d: syntax error (string didn't end)\n",
+			"%s:%ld: syntax error (string didn't end)\n",
 			curname, lineno);
 		err++;
 		dquote = 0;
 	    }
 	    if (squote) {
 		fprintf(stderr,
-			"%s:%d: syntax error (char const didn't end)\n",
+			"%s:%ld: syntax error (char const didn't end)\n",
 			curname, lineno);
 		err++;
 		squote = 0;
@@ -250,11 +255,32 @@ static void export(i)
 	    if (!comment && !squote && !dquote && paren == 0 && brace == 0
 		&& strncmp("typedef", &line[*i], 7) == 0)
 		is_typedef = 1;
+	    break;
+	case 's':
+	    if (!comment && !squote && !dquote && paren == 0 && brace == 0
+		&& strncmp("struct", &line[*i], 6) == 0)
+		is_struct = 1;
+	    break;
+	case 'e':
+	    if (!comment && !squote && !dquote && paren == 0 && brace == 0) {
+	        if (strncmp("enum", &line[*i], 4) == 0) is_enum = 1;
+		else if (strncmp("extern", &line[*i], 6) == 0) is_extern = 1;
+	    }
+	    break;
         }
-        if (! stop) {
-            if (*i >= 0) putc(line[*i], out);
-            (*i)++;
-        }
+	if (! stop) {
+	  if (*i >= 0) {
+	    if (! start) {
+	      putc(line[*i], out);
+	    } else if (! isspace(line[*i])) {
+	      if (! is_typedef && ! is_enum && ! is_extern && ! is_struct)
+		fputs("extern ", out);
+	      putc(line[*i], out);
+	      start = 0;
+	    }
+	  }
+	  (*i)++;
+	}
     } while (! stop);
 }
     
@@ -266,7 +292,8 @@ static void process(file, cpp)
     char *file, *cpp;
 {
     char cmd[1024], *s, outname[1024];
-    int brace, paren, dquote, squote, comment, i;
+    int brace, paren, dquote, squote, comment;
+    long i;
 
     strcpy(cmd, cppcmd);			/* Build cpp command line */
     strcat(cmd, cpp);
@@ -314,7 +341,7 @@ static void process(file, cpp)
             case '}':
                 if (!comment && !dquote && !squote) brace--;
 		if (brace < 0) {
-		    fprintf(stderr, "%s:%d: syntax error (too many '}'s)\n",
+		    fprintf(stderr, "%s:%ld: syntax error (too many '}'s)\n",
 			    curname, lineno);
 		    err++;
 		    brace = 0;
@@ -326,7 +353,7 @@ static void process(file, cpp)
             case ')':
                 if (!comment && !dquote && !squote) paren--;
 		if (paren < 0) {
-		    fprintf(stderr, "%s:%d: syntax error (too many ')'s)\n",
+		    fprintf(stderr, "%s:%ld: syntax error (too many ')'s)\n",
 			    curname, lineno);
 		    err++;
 		    paren = 0;
@@ -341,14 +368,14 @@ static void process(file, cpp)
 	    case '\n':
 		if (dquote) {
 		    fprintf(stderr,
-			    "%s:%d: syntax error (string didn't end)\n",
+			    "%s:%ld: syntax error (string didn't end)\n",
 			    curname, lineno);
 		    err++;
 		    dquote = 0;
 		}
 		if (squote) {
 		    fprintf(stderr,
-			    "%s:%d: syntax error (char const didn't end)\n",
+			    "%s:%ld: syntax error (char const didn't end)\n",
 			    curname, lineno);
 		    err++;
 		    squote = 0;
@@ -371,24 +398,24 @@ static void process(file, cpp)
                 else if (strncmp(&line[i], "EXPORTDEF ", 10) == 0
                     && (i == 0 || !isalnum(line[i-1]))) {
                     exportdef(i);
-                    i = strlen(line) - 1;
+                    i = (long) strlen(line) - 1;
                 }
                 break;
             }
         }
     }
     if (comment) {
-	fprintf(stderr, "%s:%d: syntax error (comment didn't end)\n",
+	fprintf(stderr, "%s:%ld: syntax error (comment didn't end)\n",
 		curname, lineno);
 	err++;
     }
     if (dquote) {
-	fprintf(stderr, "%s:%d: syntax error (string didn't end)\n",
+	fprintf(stderr, "%s:%ld: syntax error (string didn't end)\n",
 		curname, lineno);
 	err++;
     }
     if (squote) {
-	fprintf(stderr, "%s:%d: syntax error (char const didn't end)\n",
+	fprintf(stderr, "%s:%ld: syntax error (char const didn't end)\n",
 		curname, lineno);
 	err++;
     }
