@@ -9,7 +9,7 @@
  * Author: Bert Bos <bert@w3.org>
  * Created: 12 May 1998
  **/
-#include <config.h>
+#include "config.h"
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
