@@ -66,7 +66,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 18 March 2000
- * Version: $Id: hxcite.c,v 1.8 2013-10-08 16:46:21 bbos Exp $
+ * Version: $Id: hxcite.c,v 1.9 2014-03-11 12:42:56 bbos Exp $
  **/
 
 #include "config.h"
@@ -89,9 +89,6 @@
 # endif
 #endif
 
-#ifdef HAVE_ERRNO_H
-#  include <errno.h>
-#endif
 #ifdef HAVE_SEARCH_H
 #  include <search.h>
 #else
