@@ -11,10 +11,10 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: Dec 2004
- * Version: $Id: hxname2id.c,v 1.5 2013-03-23 23:18:09 bbos Exp $
+ * Version: $Id: hxname2id.c,v 1.6 2013-07-25 21:06:22 bbos Exp $
  *
  **/
-#include <config.h>
+#include "config.h"
 #include <assert.h>
 #include <ctype.h>
 #include <stdlib.h>
