@@ -6,7 +6,7 @@
  *
  * Created 9 May 1998
  * Bert Bos <bert@w3.org>
- * $Id: hxnormalize.c,v 1.17 2014-07-21 17:00:48 bbos Exp $
+ * $Id: hxnormalize.c,v 1.18 2014-09-02 17:06:32 bbos Exp $
  */
 #include "config.h"
 #include <stdio.h>
@@ -203,7 +203,7 @@ static void pp(Tree n, bool preformatted, bool allow_text,
 	  out(" \"", false);
 	  out(n->url, false);
 	  out("\"", false);
-	} else if (do_xml) {	/* XML cannot omit the system literal */
+	} else if (n->text && do_xml) {	/* XML cannot omit the system literal */
 	  out(" \"\"", false);
 	}
 	outln(">", false);
