@@ -6,9 +6,9 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 23 May 1999
- * Version: $Id: hxunpipe.c,v 1.8 2013-03-23 23:18:10 bbos Exp $
+ * Version: $Id: hxunpipe.c,v 1.9 2013-06-30 20:39:59 bbos Exp $
  */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <ctype.h>
 #include <stdlib.h>
@@ -74,12 +74,15 @@ static void put_attr(void)
   int i, j;
 
   for (j = 0; j < nrattrs; j++) {
-    for (i = 0; attrs[j][i] != ' '; i++);
+    for (i = 0; attrs[j][i] && attrs[j][i] != ' '; i++);
+    if (attrs[j][i] != ' ') errexit("Incorrect A (attribute) line\n");
     if (! eq(attrs[j] + i + 1, "IMPLIED")) {
       putchar(' ');
-      for (i = 0; attrs[j][i] != ' '; i++) putchar(attrs[j][i]);
+      for (i = 0; attrs[j][i] && attrs[j][i] != ' '; i++) putchar(attrs[j][i]);
+      if (attrs[j][i] != ' ') errexit("Incorrect A (attribute) line\n");
       putchar('=');
-      for (i++; attrs[j][i] != ' '; i++) ;	/* skip type ("CDATA") */
+      for (i++; attrs[j][i] && attrs[j][i] != ' '; i++) ; /* skip type */
+      if (attrs[j][i] != ' ') errexit("Incorrect A (attribute) line\n");
       putchar('"');
       for (i++; attrs[j][i]; i++) {
 	if (attrs[j][i] != '\\') putchar(attrs[j][i]);
