@@ -220,7 +220,7 @@ static size_t write_cb(char *buf, size_t size, size_t nitems, void *userdata)
 
 
 /* wait_for_data -- fill the read buffer up to requested # of bytes */
-static CURLMcode wait_for_data(URL_FILE *file, size_t want)
+static CURLcode wait_for_data(URL_FILE *file, size_t want)
 {
   fd_set fdread, fdwrite, fdexcep;
   struct timeval timeout;
@@ -238,12 +238,12 @@ static CURLMcode wait_for_data(URL_FILE *file, size_t want)
 
     /* Stop if the connection is closed, after checking why */
     if (!file->still_running) {
-      if (!(msg = curl_multi_info_read(multi_handle, &n))) return CURLM_OK;
-      else return msg->msg == CURLMSG_DONE ? msg->data.result : CURLM_OK;
+      if (!(msg = curl_multi_info_read(multi_handle, &n))) return CURLE_OK;
+      else return msg->msg == CURLMSG_DONE ? msg->data.result : CURLE_OK;
     }
 
     /* Stop when we have enough data */
-    if (file->buffer_pos >= want) return CURLM_OK;
+    if (file->buffer_pos >= want) return CURLE_OK;
 
     /* Determine how long to wait in select(), max is 1 second */
     curl_multi_timeout(multi_handle, &curl_timeout);
@@ -268,7 +268,7 @@ static CURLMcode wait_for_data(URL_FILE *file, size_t want)
       errexit("select error: %s\n", strerror(errno));
   }
 
-  return CURLM_OK;
+  return CURLE_OK;
 }
 
 
@@ -300,7 +300,7 @@ static ssize_t read_cb(void *cookie, char *buf, size_t n)
 
   /* Todo: set errno to something corresponding to the error */
 
-  if (wait_for_data(file, n) != CURLM_OK) {errno = EIO; return -1;}
+  if (wait_for_data(file, n) != CURLE_OK) {errno = EIO; return -1;}
 
   if (file->buffer_pos < n) n = file->buffer_pos;
   if (!buf) {errno = EFAULT; return -1;}
@@ -333,7 +333,7 @@ EXPORT FILE *fopenurl3(const conststring method, const conststring url,
   const char *h, *v, *headerline;
   cookie_io_functions_t iofuncs;
   URL_FILE *file;
-  CURLMcode rc;
+  CURLcode rc;
   int dummy;
   size_t n;
 
