@@ -4,9 +4,9 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 31 Mar 2000
- * Version: $Id: strerror.c,v 1.3 2007/10/23 11:17:08 bbos Exp $
+ * Version: $Id: strerror.c,v 1.4 2013-06-30 20:31:57 bbos Exp $
  **/
-#include <config.h>
+#include "config.h"
 #ifdef HAVE_ERRNO_H
 #  include <errno.h>
 #endif
