@@ -17,13 +17,13 @@ i=-1
 while [ $(( ( i += 1 ) <= 10 )) -ne 0 ]; do
   p=$(($PORT + $i))
   q=$(($p + 1))
-  printf "HTTP/1.1 302\r\nLocation: http://localhost:$q/\r\n\r" |\
+  printf "HTTP/1.1 302\r\nLocation: http://127.0.0.1:$q/\r\n\r" |\
     (nc -l -n -p $p || nc -l -n $p) >/dev/null 2>&1 &
 done
 
 sleep 1				# Give the servers time to start
 
-./hxextract body http://localhost:$PORT/ 2>&1 | grep -q 'Too many links'
+./hxextract body http://127.0.0.1:$PORT/ 2>&1 | grep -q 'Too many links'
 
 code=$?
 
