@@ -66,12 +66,12 @@ EXPORT const struct _Entity *lookup_entity (const char *str, unsigned int len);
 #line 36 "unent.hash"
 struct _Entity;
 
-#define TOTAL_KEYWORDS 252
+#define TOTAL_KEYWORDS 253
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 8
 #define MIN_HASH_VALUE 10
-#define MAX_HASH_VALUE 528
-/* maximum key range = 519, duplicates = 2 */
+#define MAX_HASH_VALUE 533
+/* maximum key range = 524, duplicates = 2 */
 
 #ifdef __GNUC__
 __inline
@@ -87,32 +87,32 @@ hash (str, len)
 {
   static const unsigned short asso_values[] =
     {
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529,  35,
-       15,  10,  10, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529,   3,   5, 220,   0, 253,
-      529,  75,  25, 142, 145, 165,   5,  10,   5, 190,
-       60, 529,   0, 110,  35, 197,  20, 529,  10,  40,
-        0, 529, 529, 529, 529, 529, 529,  10, 230,   5,
-      190,   0, 155,  10,  15, 100, 205, 160,  20, 125,
-      145,  45,  65, 135,  35,  90,  55,  75, 115, 115,
-        5,  54, 170, 529,  35, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529, 529, 529,
-      529, 529, 529, 529, 529, 529, 529, 529
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534,  40,
+       70,  20,  50, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 193,   5, 215,   0, 219,
+      534, 185,   5, 215, 190,  45,   5,   0,  30, 199,
+       35, 534,  15,  15,  10, 110,   0, 534,  10,  40,
+        0, 534, 534, 534, 534, 534, 534,  10, 210,   5,
+      155,   0, 200,  10,  15, 100, 175, 155,  20, 150,
+      145,  45,  65, 200,  35, 105,  55,  75, 140, 115,
+        0, 250,  80, 534, 100, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534, 534, 534,
+      534, 534, 534, 534, 534, 534, 534, 534
     };
   return len + asso_values[(unsigned char)str[1]+2] + asso_values[(unsigned char)str[0]] + asso_values[(unsigned char)str[len - 1]];
 }
@@ -134,10 +134,6 @@ lookup_entity (str, len)
       {"ecirc", 234},
 #line 112 "unent.hash"
       {"eacute", 233},
-#line 73 "unent.hash"
-      {"Acirc", 194},
-#line 72 "unent.hash"
-      {"Aacute", 193},
 #line 59 "unent.hash"
       {"acute", 180},
 #line 105 "unent.hash"
@@ -170,7 +166,7 @@ lookup_entity (str, len)
       {"lambda", 955},
 #line 248 "unent.hash"
       {"lceil", 8968},
-#line 286 "unent.hash"
+#line 287 "unent.hash"
       {"Dagger", 8225},
 #line 222 "unent.hash"
       {"radic", 8730},
@@ -190,14 +186,12 @@ lookup_entity (str, len)
       {"rceil", 8969},
 #line 199 "unent.hash"
       {"larr", 8592},
-#line 132 "unent.hash"
-      {"yacute", 253},
+#line 145 "unent.hash"
+      {"Kappa", 922},
 #line 196 "unent.hash"
       {"real", 8476},
-#line 264 "unent.hash"
+#line 265 "unent.hash"
       {"oelig", 339},
-#line 76 "unent.hash"
-      {"Aring", 197},
 #line 41 "unent.hash"
       {"cent", 162},
 #line 50 "unent.hash"
@@ -222,83 +216,69 @@ lookup_entity (str, len)
       {"raquo", 187},
 #line 251 "unent.hash"
       {"rfloor", 8971},
-#line 77 "unent.hash"
-      {"AElig", 198},
-#line 138 "unent.hash"
-      {"Gamma", 915},
+#line 154 "unent.hash"
+      {"Tau", 932},
+#line 191 "unent.hash"
+      {"Prime", 8243},
 #line 189 "unent.hash"
       {"hellip", 8230},
 #line 204 "unent.hash"
       {"crarr", 8629},
-#line 287 "unent.hash"
+#line 288 "unent.hash"
       {"permil", 8240},
-#line 213 "unent.hash"
-      {"empty", 8709},
+#line 165 "unent.hash"
+      {"zeta", 950},
 #line 184 "unent.hash"
       {"omega", 969},
 #line 111 "unent.hash"
       {"egrave", 232},
-#line 71 "unent.hash"
-      {"Agrave", 192},
 #line 117 "unent.hash"
       {"icirc", 238},
 #line 116 "unent.hash"
       {"iacute", 237},
-#line 271 "unent.hash"
+#line 272 "unent.hash"
       {"emsp", 8195},
 #line 197 "unent.hash"
       {"trade", 8482},
 #line 103 "unent.hash"
       {"agrave", 224},
-#line 154 "unent.hash"
-      {"Tau", 932},
 #line 200 "unent.hash"
       {"uarr", 8593},
-#line 191 "unent.hash"
-      {"Prime", 8243},
-#line 257 "unent.hash"
-      {"hearts", 9829},
+#line 98 "unent.hash"
+      {"Ucirc", 219},
+#line 97 "unent.hash"
+      {"Uacute", 218},
 #line 260 "unent.hash"
       {"amp", 38},
-#line 74 "unent.hash"
-      {"Atilde", 195},
 #line 190 "unent.hash"
       {"prime", 8242},
-#line 88 "unent.hash"
-      {"Ntilde", 209},
-#line 166 "unent.hash"
-      {"eta", 951},
 #line 211 "unent.hash"
       {"part", 8706},
 #line 186 "unent.hash"
       {"upsih", 978},
-#line 106 "unent.hash"
-      {"atilde", 227},
-#line 119 "unent.hash"
-      {"eth", 240},
-#line 270 "unent.hash"
+#line 271 "unent.hash"
       {"ensp", 8194},
 #line 40 "unent.hash"
       {"iexcl", 161},
+#line 257 "unent.hash"
+      {"hearts", 9829},
 #line 227 "unent.hash"
       {"or", 8744},
 #line 179 "unent.hash"
       {"tau", 964},
 #line 114 "unent.hash"
       {"euml", 235},
-#line 102 "unent.hash"
-      {"szlig", 223},
+#line 212 "unent.hash"
+      {"exist", 8707},
 #line 127 "unent.hash"
       {"oslash", 248},
-#line 75 "unent.hash"
-      {"Auml", 196},
 #line 47 "unent.hash"
       {"uml", 168},
 #line 246 "unent.hash"
       {"perp", 8869},
-#line 279 "unent.hash"
+#line 280 "unent.hash"
       {"lsquo", 8216},
-#line 288 "unent.hash"
+#line 289 "unent.hash"
       {"lsaquo", 8249},
 #line 107 "unent.hash"
       {"auml", 228},
@@ -306,405 +286,427 @@ lookup_entity (str, len)
       {"image", 8465},
 #line 121 "unent.hash"
       {"ograve", 242},
-#line 85 "unent.hash"
-      {"Icirc", 206},
-#line 84 "unent.hash"
-      {"Iacute", 205},
-#line 233 "unent.hash"
-      {"cong", 8773},
+#line 166 "unent.hash"
+      {"eta", 951},
+#line 261 "unent.hash"
+      {"apos", 39},
 #line 234 "unent.hash"
       {"asymp", 8776},
+#line 106 "unent.hash"
+      {"atilde", 227},
 #line 235 "unent.hash"
       {"ne", 8800},
-#line 46 "unent.hash"
-      {"sect", 167},
-#line 280 "unent.hash"
+#line 119 "unent.hash"
+      {"eth", 240},
+#line 281 "unent.hash"
       {"rsquo", 8217},
-#line 289 "unent.hash"
-      {"rsaquo", 8250},
-#line 136 "unent.hash"
-      {"Alpha", 913},
 #line 290 "unent.hash"
+      {"rsaquo", 8250},
+#line 291 "unent.hash"
       {"euro", 8364},
 #line 214 "unent.hash"
       {"nabla", 8711},
-#line 124 "unent.hash"
-      {"otilde", 245},
-#line 54 "unent.hash"
-      {"macr", 175},
+#line 266 "unent.hash"
+      {"Scaron", 352},
+#line 269 "unent.hash"
+      {"circ", 710},
 #line 160 "unent.hash"
       {"alpha", 945},
-#line 268 "unent.hash"
-      {"circ", 710},
-#line 244 "unent.hash"
-      {"oplus", 8853},
-#line 267 "unent.hash"
-      {"Yuml", 376},
+#line 46 "unent.hash"
+      {"sect", 167},
 #line 169 "unent.hash"
       {"kappa", 954},
+#line 88 "unent.hash"
+      {"Ntilde", 209},
+#line 55 "unent.hash"
+      {"deg", 176},
+#line 268 "unent.hash"
+      {"Yuml", 376},
+#line 163 "unent.hash"
+      {"delta", 948},
 #line 128 "unent.hash"
       {"ugrave", 249},
-#line 262 "unent.hash"
-      {"gt", 62},
 #line 125 "unent.hash"
       {"ouml", 246},
-#line 145 "unent.hash"
-      {"Kappa", 922},
+#line 153 "unent.hash"
+      {"Sigma", 931},
 #line 164 "unent.hash"
       {"epsilon", 949},
 #line 229 "unent.hash"
       {"cup", 8746},
 #line 223 "unent.hash"
       {"prop", 8733},
-#line 101 "unent.hash"
-      {"THORN", 222},
-#line 261 "unent.hash"
-      {"lt", 60},
-#line 134 "unent.hash"
-      {"yuml", 255},
-#line 165 "unent.hash"
-      {"zeta", 950},
+#line 244 "unent.hash"
+      {"oplus", 8853},
+#line 124 "unent.hash"
+      {"otilde", 245},
+#line 147 "unent.hash"
+      {"Mu", 924},
+#line 54 "unent.hash"
+      {"macr", 175},
 #line 192 "unent.hash"
       {"oline", 8254},
 #line 194 "unent.hash"
       {"weierp", 8472},
-#line 148 "unent.hash"
-      {"Nu", 925},
-#line 48 "unent.hash"
-      {"copy", 169},
+#line 202 "unent.hash"
+      {"darr", 8595},
+#line 143 "unent.hash"
+      {"Theta", 920},
+#line 286 "unent.hash"
+      {"dagger", 8224},
+#line 73 "unent.hash"
+      {"Acirc", 194},
+#line 72 "unent.hash"
+      {"Aacute", 193},
+#line 138 "unent.hash"
+      {"Gamma", 915},
+#line 115 "unent.hash"
+      {"igrave", 236},
+#line 263 "unent.hash"
+      {"gt", 62},
 #line 91 "unent.hash"
       {"Ocirc", 212},
 #line 90 "unent.hash"
       {"Oacute", 211},
-#line 147 "unent.hash"
-      {"Mu", 924},
-#line 275 "unent.hash"
-      {"lrm", 8206},
-#line 115 "unent.hash"
-      {"igrave", 236},
-#line 98 "unent.hash"
-      {"Ucirc", 219},
-#line 97 "unent.hash"
-      {"Uacute", 218},
+#line 158 "unent.hash"
+      {"Psi", 936},
+#line 131 "unent.hash"
+      {"uuml", 252},
+#line 270 "unent.hash"
+      {"tilde", 732},
+#line 96 "unent.hash"
+      {"Ugrave", 217},
+#line 262 "unent.hash"
+      {"lt", 60},
+#line 233 "unent.hash"
+      {"cong", 8773},
+#line 102 "unent.hash"
+      {"szlig", 223},
+#line 148 "unent.hash"
+      {"Nu", 925},
+#line 230 "unent.hash"
+      {"int", 8747},
 #line 242 "unent.hash"
       {"sube", 8838},
 #line 243 "unent.hash"
       {"supe", 8839},
-#line 236 "unent.hash"
-      {"equiv", 8801},
-#line 44 "unent.hash"
-      {"yen", 165},
-#line 55 "unent.hash"
-      {"deg", 176},
-#line 131 "unent.hash"
-      {"uuml", 252},
-#line 163 "unent.hash"
-      {"delta", 948},
-#line 221 "unent.hash"
-      {"lowast", 8727},
-#line 58 "unent.hash"
-      {"sup3", 179},
-#line 269 "unent.hash"
-      {"tilde", 732},
-#line 255 "unent.hash"
-      {"spades", 9824},
-#line 230 "unent.hash"
-      {"int", 8747},
-#line 57 "unent.hash"
-      {"sup2", 178},
-#line 282 "unent.hash"
-      {"ldquo", 8220},
-#line 67 "unent.hash"
-      {"frac14", 188},
-#line 69 "unent.hash"
-      {"frac34", 190},
-#line 65 "unent.hash"
-      {"ordm", 186},
-#line 212 "unent.hash"
-      {"exist", 8707},
-#line 68 "unent.hash"
-      {"frac12", 189},
-#line 202 "unent.hash"
-      {"darr", 8595},
-#line 193 "unent.hash"
-      {"frasl", 8260},
-#line 285 "unent.hash"
-      {"dagger", 8224},
-#line 158 "unent.hash"
-      {"Psi", 936},
-#line 118 "unent.hash"
-      {"iuml", 239},
-#line 283 "unent.hash"
-      {"rdquo", 8221},
-#line 266 "unent.hash"
-      {"scaron", 353},
-#line 174 "unent.hash"
-      {"omicron", 959},
-#line 183 "unent.hash"
-      {"psi", 968},
-#line 64 "unent.hash"
-      {"sup1", 185},
-#line 256 "unent.hash"
-      {"clubs", 9827},
-#line 78 "unent.hash"
-      {"Ccedil", 199},
-#line 83 "unent.hash"
-      {"Igrave", 204},
-#line 168 "unent.hash"
-      {"iota", 953},
-#line 159 "unent.hash"
-      {"Omega", 937},
-#line 70 "unent.hash"
-      {"iquest", 191},
-#line 152 "unent.hash"
-      {"Rho", 929},
-#line 161 "unent.hash"
-      {"beta", 946},
-#line 143 "unent.hash"
-      {"Theta", 920},
-#line 245 "unent.hash"
-      {"otimes", 8855},
-#line 49 "unent.hash"
-      {"ordf", 170},
-#line 265 "unent.hash"
-      {"Scaron", 352},
-#line 180 "unent.hash"
-      {"upsilon", 965},
+#line 85 "unent.hash"
+      {"Icirc", 206},
+#line 84 "unent.hash"
+      {"Iacute", 205},
+#line 87 "unent.hash"
+      {"ETH", 208},
+#line 276 "unent.hash"
+      {"lrm", 8206},
 #line 81 "unent.hash"
       {"Ecirc", 202},
 #line 80 "unent.hash"
       {"Eacute", 201},
-#line 178 "unent.hash"
-      {"sigma", 963},
-#line 120 "unent.hash"
-      {"ntilde", 241},
-#line 173 "unent.hash"
-      {"xi", 958},
 #line 226 "unent.hash"
       {"and", 8743},
-#line 43 "unent.hash"
-      {"curren", 164},
-#line 149 "unent.hash"
-      {"Xi", 926},
-#line 240 "unent.hash"
-      {"sup", 8835},
-#line 209 "unent.hash"
-      {"hArr", 8660},
+#line 161 "unent.hash"
+      {"beta", 946},
+#line 101 "unent.hash"
+      {"THORN", 222},
+#line 152 "unent.hash"
+      {"Rho", 929},
+#line 118 "unent.hash"
+      {"iuml", 239},
+#line 78 "unent.hash"
+      {"Ccedil", 199},
+#line 174 "unent.hash"
+      {"omicron", 959},
+#line 183 "unent.hash"
+      {"psi", 968},
+#line 58 "unent.hash"
+      {"sup3", 179},
 #line 167 "unent.hash"
       {"theta", 952},
-#line 231 "unent.hash"
-      {"there4", 8756},
-#line 205 "unent.hash"
-      {"lArr", 8656},
-#line 263 "unent.hash"
-      {"OElig", 338},
-#line 86 "unent.hash"
-      {"Iuml", 207},
-#line 153 "unent.hash"
-      {"Sigma", 931},
-#line 95 "unent.hash"
-      {"Oslash", 216},
-#line 198 "unent.hash"
-      {"alefsym", 8501},
-#line 176 "unent.hash"
-      {"rho", 961},
-#line 144 "unent.hash"
-      {"Iota", 921},
-#line 207 "unent.hash"
-      {"rArr", 8658},
-#line 89 "unent.hash"
-      {"Ograve", 210},
-#line 278 "unent.hash"
-      {"mdash", 8212},
-#line 87 "unent.hash"
-      {"ETH", 208},
-#line 96 "unent.hash"
-      {"Ugrave", 217},
-#line 247 "unent.hash"
-      {"sdot", 8901},
-#line 276 "unent.hash"
-      {"rlm", 8207},
-#line 259 "unent.hash"
-      {"quot", 34},
-#line 94 "unent.hash"
-      {"times", 215},
-#line 92 "unent.hash"
-      {"Otilde", 213},
-#line 182 "unent.hash"
-      {"chi", 967},
-#line 218 "unent.hash"
-      {"prod", 8719},
-#line 224 "unent.hash"
-      {"infin", 8734},
-#line 210 "unent.hash"
-      {"forall", 8704},
-#line 171 "unent.hash"
-      {"mu", 956},
-#line 277 "unent.hash"
-      {"ndash", 8211},
-#line 151 "unent.hash"
-      {"Pi", 928},
-#line 215 "unent.hash"
-      {"isin", 8712},
-#line 45 "unent.hash"
-      {"brvbar", 166},
-#line 175 "unent.hash"
-      {"pi", 960},
-#line 254 "unent.hash"
-      {"loz", 9674},
-#line 93 "unent.hash"
-      {"Ouml", 214},
-#line 281 "unent.hash"
-      {"sbquo", 8218},
-#line 272 "unent.hash"
-      {"thinsp", 8201},
-#line 219 "unent.hash"
-      {"sum", 8721},
-#line 206 "unent.hash"
-      {"uArr", 8657},
-#line 60 "unent.hash"
-      {"micro", 181},
 #line 99 "unent.hash"
       {"Uuml", 220},
-#line 172 "unent.hash"
-      {"nu", 957},
-#line 51 "unent.hash"
-      {"not", 172},
-#line 187 "unent.hash"
-      {"piv", 982},
-#line 62 "unent.hash"
-      {"middot", 183},
-#line 52 "unent.hash"
-      {"shy", 173},
-#line 126 "unent.hash"
-      {"divide", 247},
-#line 79 "unent.hash"
-      {"Egrave", 200},
-#line 56 "unent.hash"
-      {"plusmn", 177},
-#line 156 "unent.hash"
-      {"Phi", 934},
-#line 188 "unent.hash"
-      {"bull", 8226},
-#line 181 "unent.hash"
-      {"phi", 966},
-#line 232 "unent.hash"
-      {"sim", 8764},
-#line 135 "unent.hash"
-      {"fnof", 402},
-#line 220 "unent.hash"
-      {"minus", 8722},
-#line 142 "unent.hash"
-      {"Eta", 919},
+#line 236 "unent.hash"
+      {"equiv", 8801},
+#line 255 "unent.hash"
+      {"spades", 9824},
+#line 65 "unent.hash"
+      {"ordm", 186},
+#line 267 "unent.hash"
+      {"scaron", 353},
+#line 173 "unent.hash"
+      {"xi", 958},
+#line 176 "unent.hash"
+      {"rho", 961},
+#line 159 "unent.hash"
+      {"Omega", 937},
+#line 256 "unent.hash"
+      {"clubs", 9827},
+#line 132 "unent.hash"
+      {"yacute", 253},
+#line 180 "unent.hash"
+      {"upsilon", 965},
+#line 76 "unent.hash"
+      {"Aring", 197},
+#line 64 "unent.hash"
+      {"sup1", 185},
+#line 70 "unent.hash"
+      {"iquest", 191},
+#line 149 "unent.hash"
+      {"Xi", 926},
+#line 209 "unent.hash"
+      {"hArr", 8660},
+#line 283 "unent.hash"
+      {"ldquo", 8220},
+#line 43 "unent.hash"
+      {"curren", 164},
+#line 205 "unent.hash"
+      {"lArr", 8656},
+#line 178 "unent.hash"
+      {"sigma", 963},
+#line 218 "unent.hash"
+      {"prod", 8719},
+#line 193 "unent.hash"
+      {"frasl", 8260},
+#line 221 "unent.hash"
+      {"lowast", 8727},
+#line 182 "unent.hash"
+      {"chi", 967},
+#line 284 "unent.hash"
+      {"rdquo", 8221},
+#line 231 "unent.hash"
+      {"there4", 8756},
+#line 240 "unent.hash"
+      {"sup", 8835},
+#line 207 "unent.hash"
+      {"rArr", 8658},
+#line 120 "unent.hash"
+      {"ntilde", 241},
+#line 151 "unent.hash"
+      {"Pi", 928},
+#line 57 "unent.hash"
+      {"sup2", 178},
+#line 95 "unent.hash"
+      {"Oslash", 216},
+#line 245 "unent.hash"
+      {"otimes", 8855},
 #line 155 "unent.hash"
       {"Upsilon", 933},
-#line 150 "unent.hash"
-      {"Omicron", 927},
+#line 71 "unent.hash"
+      {"Agrave", 192},
+#line 213 "unent.hash"
+      {"empty", 8709},
+#line 273 "unent.hash"
+      {"thinsp", 8201},
+#line 254 "unent.hash"
+      {"loz", 9674},
+#line 49 "unent.hash"
+      {"ordf", 170},
+#line 89 "unent.hash"
+      {"Ograve", 210},
+#line 45 "unent.hash"
+      {"brvbar", 166},
+#line 282 "unent.hash"
+      {"sbquo", 8218},
+#line 67 "unent.hash"
+      {"frac14", 188},
+#line 69 "unent.hash"
+      {"frac34", 190},
+#line 198 "unent.hash"
+      {"alefsym", 8501},
+#line 156 "unent.hash"
+      {"Phi", 934},
+#line 168 "unent.hash"
+      {"iota", 953},
+#line 224 "unent.hash"
+      {"infin", 8734},
+#line 126 "unent.hash"
+      {"divide", 247},
+#line 94 "unent.hash"
+      {"times", 215},
+#line 83 "unent.hash"
+      {"Igrave", 204},
+#line 175 "unent.hash"
+      {"pi", 960},
+#line 215 "unent.hash"
+      {"isin", 8712},
+#line 79 "unent.hash"
+      {"Egrave", 200},
+#line 206 "unent.hash"
+      {"uArr", 8657},
+#line 68 "unent.hash"
+      {"frac12", 189},
+#line 75 "unent.hash"
+      {"Auml", 196},
+#line 277 "unent.hash"
+      {"rlm", 8207},
+#line 172 "unent.hash"
+      {"nu", 957},
+#line 93 "unent.hash"
+      {"Ouml", 214},
+#line 74 "unent.hash"
+      {"Atilde", 195},
+#line 171 "unent.hash"
+      {"mu", 956},
+#line 181 "unent.hash"
+      {"phi", 966},
+#line 92 "unent.hash"
+      {"Otilde", 213},
+#line 188 "unent.hash"
+      {"bull", 8226},
+#line 136 "unent.hash"
+      {"Alpha", 913},
+#line 86 "unent.hash"
+      {"Iuml", 207},
+#line 60 "unent.hash"
+      {"micro", 181},
 #line 82 "unent.hash"
       {"Euml", 203},
-#line 185 "unent.hash"
-      {"thetasym", 977},
-#line 42 "unent.hash"
-      {"pound", 163},
+#line 56 "unent.hash"
+      {"plusmn", 177},
+#line 187 "unent.hash"
+      {"piv", 982},
+#line 247 "unent.hash"
+      {"sdot", 8901},
+#line 278 "unent.hash"
+      {"ndash", 8211},
+#line 62 "unent.hash"
+      {"middot", 183},
 #line 39 "unent.hash"
       {"nbsp", 160},
-#line 217 "unent.hash"
-      {"ni", 8715},
+#line 279 "unent.hash"
+      {"mdash", 8212},
+#line 142 "unent.hash"
+      {"Eta", 919},
+#line 219 "unent.hash"
+      {"sum", 8721},
+#line 259 "unent.hash"
+      {"quot", 34},
 #line 133 "unent.hash"
       {"thorn", 254},
-#line 177 "unent.hash"
-      {"sigmaf", 962},
-#line 216 "unent.hash"
-      {"notin", 8713},
-#line 274 "unent.hash"
-      {"zwj", 8205},
-#line 273 "unent.hash"
-      {"zwnj", 8204},
-#line 284 "unent.hash"
-      {"bdquo", 8222},
-#line 239 "unent.hash"
-      {"sub", 8834},
+#line 185 "unent.hash"
+      {"thetasym", 977},
+#line 134 "unent.hash"
+      {"yuml", 255},
+#line 77 "unent.hash"
+      {"AElig", 198},
+#line 150 "unent.hash"
+      {"Omicron", 927},
+#line 264 "unent.hash"
+      {"OElig", 338},
+#line 217 "unent.hash"
+      {"ni", 8715},
+#line 51 "unent.hash"
+      {"not", 172},
 #line 140 "unent.hash"
       {"Epsilon", 917},
-#line 258 "unent.hash"
-      {"diams", 9830},
+#line 44 "unent.hash"
+      {"yen", 165},
 #line 208 "unent.hash"
       {"dArr", 8659},
+#line 232 "unent.hash"
+      {"sim", 8764},
+#line 220 "unent.hash"
+      {"minus", 8722},
+#line 258 "unent.hash"
+      {"diams", 9830},
+#line 42 "unent.hash"
+      {"pound", 163},
+#line 210 "unent.hash"
+      {"forall", 8704},
+#line 144 "unent.hash"
+      {"Iota", 921},
+#line 239 "unent.hash"
+      {"sub", 8834},
 #line 241 "unent.hash"
       {"nsub", 8836},
+#line 48 "unent.hash"
+      {"copy", 169},
+#line 285 "unent.hash"
+      {"bdquo", 8222},
+#line 177 "unent.hash"
+      {"sigmaf", 962},
+#line 135 "unent.hash"
+      {"fnof", 402},
 #line 157 "unent.hash"
-      {"Chi", 935}
+      {"Chi", 935},
+#line 216 "unent.hash"
+      {"notin", 8713},
+#line 275 "unent.hash"
+      {"zwj", 8205},
+#line 274 "unent.hash"
+      {"zwnj", 8204},
+#line 52 "unent.hash"
+      {"shy", 173}
     };
 
   static const short lookup[] =
     {
         -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
-        -1,   -1,    0,    1,   -1,    2,    3,    4,
-        -1,   -1,   -1,   -1,    5,    6,    7,   -1,
-         8,    9,   10,   -1,   -1,   11,   12,   13,
-        14,   -1,   -1,   15,   -1,   -1,   -1,   16,
-        17,   18,   -1,   -1,   -1,   19,   20,   -1,
-        -1,   -1,   21,   22,   -1,   -1,   23,   24,
-        25,   -1,   26,   27,   28,   -1,   -1,   -1,
-        29,   30,   -1,   -1,   -1,   31,   32,   -1,
-        -1,   33,   34,   35,   36,   -1,   37,   38,
-        39,   -1,   -1,   -1,   40,   41,   42,   -1,
-        43,   -1,   44,   45,   -1,   46,   -1,   47,
-        48,   -1,   -1,   -1,   49,   50,   -1,   -1,
-        51,   52,   53,   -1,   -1,   54,   55,   56,
-        -1,   -1,   57,   58,   59,   -1,   60,   61,
-        62,   63,   -1,   64,   65,   66,   67,   -1,
-        68,   69,   70,   71,   -1,   72,   73,   74,
-        -1,   75,   76,   77,   78,   79,   80,   81,
-        82,   83,   84,   -1,   -1,   85,   86,   87,
-        88,   89,   90,   91,   -1,   92,   -1,   93,
-        94,   95,   -1,   96,   97,   98,   99,   -1,
-        -1,  100,  101,   -1,   -1,   -1,  102,  103,
-        -1,   -1,   -1,  104,  105,  106,  107,   -1,
-       108,  109,   -1,  110,  111,  112,  113,   -1,
-       114,  115,  116,  117,  118,  119,  120,   -1,
-       121,  122,  123,  124,   -1,   -1,  125,  126,
-       127, -470,  130,   -1,  131,  132,  133,  134,
-       135, -124,   -2,  136,  137,  138,   -1,  139,
-       140,  141, -480, -110,   -2,  144,  145,  146,
-        -1,   -1,  147,  148,  149,   -1,  150,  151,
-       152,  153,  154,  155,  156,  157,  158,   -1,
-       159,  160,  161,  162,   -1,  163,  164,  165,
-       166,   -1,   -1,  167,   -1,  168,  169,  170,
-       171,  172,  173,  174,  175,   -1,   -1,  176,
-       177,  178,  179,  180,  181,   -1,   -1,  182,
-       183,  184,   -1,   -1,   -1,  185,  186,  187,
-       188,   -1,   -1,  189,   -1,   -1,  190,   -1,
-       191,   -1,   -1,   -1,  192,  193,   -1,  194,
-       195,   -1,   -1,   -1,  196,  197,  198,  199,
-        -1,  200,  201,  202,  203,  204,   -1,   -1,
-       205,   -1,  206,   -1,  207,   -1,  208,  209,
-       210,  211,  212,  213,   -1,  214,  215,  216,
-       217,  218,  219,   -1,   -1,   -1,   -1,  220,
-        -1,   -1,  221,   -1,   -1,   -1,   -1,   -1,
-       222,   -1,   -1,   -1,  223,   -1,   -1,  224,
-        -1,  225,   -1,   -1,   -1,   -1,   -1,   -1,
-       226,  227,   -1,   -1,   -1,  228,   -1,   -1,
-        -1,   -1,  229,  230,  231,  232,   -1,   -1,
-       233,   -1,   -1,  234,   -1,   -1,   -1,   -1,
-       235,  236,   -1,  237,   -1,   -1,   -1,   -1,
-        -1,   -1,   -1,   -1,  238,   -1,   -1,  239,
-        -1,   -1,  240,  241,   -1,   -1,   -1,   -1,
-        -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
-        -1,   -1,   -1,   -1,   -1,   -1,  242,   -1,
-       243,  244,   -1,  245,   -1,   -1,  246,   -1,
-       247,   -1,   -1,   -1,   -1,  248,   -1,   -1,
-        -1,  249,   -1,   -1,   -1,   -1,  250,   -1,
+        -1,   -1,    0,    1,   -1,   -1,   -1,    2,
+        -1,   -1,   -1,   -1,    3,    4,    5,   -1,
+         6,    7,    8,   -1,   -1,    9,   10,   11,
+        12,   -1,   -1,   13,   -1,   -1,   -1,   14,
+        15,   16,   -1,   -1,   -1,   17,   18,   -1,
+        -1,   -1,   19,   20,   -1,   -1,   21,   22,
+        23,   -1,   24,   25,   26,   -1,   -1,   -1,
+        27,   28,   -1,   -1,   -1,   29,   30,   -1,
+        -1,   -1,   31,   32,   33,   -1,   34,   35,
+        36,   -1,   -1,   -1,   37,   38,   39,   -1,
+        40,   -1,   41,   42,   -1,   43,   -1,   44,
+        45,   -1,   -1,   -1,   46,   47,   -1,   -1,
+        48,   49,   50,   -1,   -1,   -1,   51,   52,
+        -1,   -1,   53,   54,   55,   -1,   -1,   56,
+        57,   58,   -1,   59,   -1,   60,   -1,   -1,
+        -1,   61,   62,   -1,   -1,   -1,   63,   64,
+        65,   66,   67,   68,   69,   70,   -1,   71,
+        72,   73,   74,   -1,   -1,   75,   76,   77,
+        -1,   78,   79,   80,   81,   82,   83,   -1,
+        84,   85,   -1,   -1,   86,   87,   88,   -1,
+        -1,   89,   90,   -1,   -1,   -1,   91,   92,
+        93,   -1,   94,   95,   96,   97,   -1,   -1,
+        98,   99,   -1,  100,  101,  102,  103,  104,
+       105,   -1,  106,  107,  108,   -1,   -1,  109,
+       110,  111,   -1,  112,  113,  114,  115,  116,
+        -1,  117,  118,   -1,   -1,  119,  120,  121,
+       122,  123,   -1,  124,  125,   -1,  126,  127,
+      -485,  130,  131,  132,  133,  134,  135, -125,
+        -2,  136,  137,  138,   -1,   -1,  139,  140,
+        -1,  141,  142,  143,  144,  145,   -1,   -1,
+        -1,  146,  147,  148,   -1,   -1,  149,   -1,
+       150,  151,  152,  153,  154,  155,  156,  157,
+       158,   -1,  159,  160,   -1,  161,  162,  163,
+        -1,   -1,  164,  165,   -1,   -1,   -1,  166,
+       167,  168,   -1,  169,   -1,  170,  171,   -1,
+       172,  173,   -1,  174,  175,   -1,  176,  177,
+       178,  179,   -1,  180,  181,  182,   -1,  183,
+       184,  185,  186,   -1,   -1,   -1,  187, -571,
+       190,  191,  192,  193,  194,  -65,   -2,   -1,
+       195,  196,  197,   -1,  198,  199,   -1,   -1,
+        -1,  200,   -1,  201,  202,  203,   -1,   -1,
+        -1,  204,  205,  206,   -1,   -1,  207,  208,
+        -1,  209,   -1,   -1,   -1,  210,   -1,   -1,
+        -1,  211,  212,  213,   -1,   -1,  214,   -1,
+        -1,  215,   -1,  216,  217,  218,  219,   -1,
+        -1,  220,  221,   -1,  222,  223,  224,   -1,
+        -1,   -1,   -1,   -1,  225,   -1,   -1,   -1,
+        -1,   -1,   -1,   -1,  226,  227,   -1,   -1,
+        -1,  228,   -1,   -1,  229,   -1,   -1,  230,
+        -1,   -1,  231,  232,   -1,   -1,  233,   -1,
+       234,  235,   -1,   -1,   -1,  236,   -1,  237,
+        -1,   -1,   -1,   -1,  238,   -1,   -1,   -1,
+        -1,  239,  240,   -1,   -1,  241,   -1,   -1,
+        -1,  242,  243,   -1,   -1,   -1,   -1,   -1,
         -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
         -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
+        -1,   -1,   -1,  244,  245,   -1,   -1,   -1,
+        -1,   -1,  246,   -1,   -1,  247,   -1,   -1,
         -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
         -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
+        -1,   -1,   -1,   -1,   -1,  248,   -1,  249,
+        -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
+        -1,   -1,   -1,   -1,  250,  251,   -1,   -1,
         -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
         -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
-        -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
-        -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
-        -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
-       251
+        -1,   -1,   -1,   -1,   -1,  252
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
@@ -741,5 +743,5 @@ lookup_entity (str, len)
     }
   return 0;
 }
-#line 291 "unent.hash"
+#line 292 "unent.hash"
 
