@@ -3,13 +3,15 @@
  *
  * Assumes the strings are encoded in UTF-8
  *
+ * Bug: URL_s_absolutize("foo/bar", "../") yields "" but should return "./"
+ *
  * Copyright  1994-2011 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 7 March 1999
  */
-#include <config.h>
+#include "config.h"
 #include <stdlib.h>
 #include <assert.h>
 #include <stdio.h>
